mercurial/revset.py
changeset 33855 457d1ebf151b
parent 33779 9fa874fb34e1
child 34011 1b28525e6698
--- a/mercurial/revset.py	Tue Aug 15 17:22:57 2017 -0700
+++ b/mercurial/revset.py	Wed Aug 16 16:48:41 2017 +0200
@@ -470,6 +470,7 @@
     """Mutable changesets marked as successors of public changesets.
 
     Only non-public and non-obsolete changesets can be `phasedivergent`.
+    (EXPERIMENTAL)
     """
     # i18n: "phasedivergent" is a keyword
     getargs(x, 0, 0, _("phasedivergent takes no arguments"))
@@ -728,7 +729,8 @@
 @predicate('contentdivergent()', safe=True)
 def contentdivergent(repo, subset, x):
     """
-    Final successors of changesets with an alternative set of final successors.
+    Final successors of changesets with an alternative set of final
+    successors. (EXPERIMENTAL)
     """
     # i18n: "contentdivergent" is a keyword
     getargs(x, 0, 0, _("contentdivergent takes no arguments"))
@@ -1943,7 +1945,7 @@
 
 @predicate('orphan()', safe=True)
 def orphan(repo, subset, x):
     """Non-obsolete changesets with obsolete ancestors.
     """
     # i18n: "orphan" is a keyword
     getargs(x, 0, 0, _("orphan takes no arguments"))
@@ -1943,7 +1945,7 @@
 @predicate('orphan()', safe=True)
 def orphan(repo, subset, x):
-    """Non-obsolete changesets with obsolete ancestors.
+    """Non-obsolete changesets with obsolete ancestors. (EXPERIMENTAL)
     """
     # i18n: "orphan" is a keyword